# spud
A cross-platform, [Spigot](https://www.spigotmc.org/) plugin manager that adheres to
[Unix philosophy](https://en.wikipedia.org/wiki/Unix_philosophy) and conventions.


Work in progress, currently only the install action is implemented.


## Installation
Install with `pip install spud-mc`

Run `spud -h` to see all the options.

Inspired by [pluGET](https://github.com/Neocky/pluGET)
